==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ScaleRuleAuthArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Auth Secrets for Container App Scale Rule
 * @property secretRef Name of the Container App secret from which to pull the auth params.
 * @property triggerParameter Trigger Parameter that uses the secret
 */
public data class ScaleRuleAuthArgs(
    public val secretRef: Output<String>? = null,
    public val triggerParameter: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs =
        com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs.builder()
            .secretRef(secretRef?.applyValue({ args0 -> args0 }))
            .triggerParameter(triggerParameter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScaleRuleAuthArgs].
 */
@PulumiTagMarker
public class ScaleRuleAuthArgsBuilder internal constructor() {
    private var secretRef: Output<String>? = null

    private var triggerParameter: Output<String>? = null

    /**
     * @param value Name of the Container App secret from which to pull the auth params.
     */
    @JvmName("uysravkeduvlclon")
    public suspend fun secretRef(`value`: Output<String>) {
        this.secretRef = value
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("veijdtaowkasksex")
    public suspend fun triggerParameter(`value`: Output<String>) {
        this.triggerParameter = value
    }

    /**
     * @param value Name of the Container App secret from which to pull the auth params.
     */
    @JvmName("kvldtoasohvkghjl")
    public suspend fun secretRef(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretRef = mapped
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("naydsfgmjrtlcwyr")
    public suspend fun triggerParameter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerParameter = mapped
    }

    internal fun build(): ScaleRuleAuthArgs = ScaleRuleAuthArgs(
        secretRef = secretRef,
        triggerParameter = triggerParameter,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/web/kotlin/inputs/ScaleRuleAuthArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.web.kotlin.inputs

import com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import kotlin.String
import kotlin.Suppress
import kotlin.jvm.JvmName

/**
 * Auth Secrets for Container App Scale Rule
 * @property secretRef Name of the Container App secret from which to pull the auth params.
 * @property triggerParameter Trigger Parameter that uses the secret
 */
public data class ScaleRuleAuthArgs(
    public val secretRef: Output<String>? = null,
    public val triggerParameter: Output<String>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs> {
    override fun toJava(): com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs =
        com.pulumi.azurenative.web.inputs.ScaleRuleAuthArgs.builder()
            .secretRef(secretRef?.applyValue({ args0 -> args0 }))
            .triggerParameter(triggerParameter?.applyValue({ args0 -> args0 })).build()
}

/**
 * Builder for [ScaleRuleAuthArgs].
 */
@PulumiTagMarker
public class ScaleRuleAuthArgsBuilder internal constructor() {
    private var secretRef: Output<String>? = null

    private var triggerParameter: Output<String>? = null

    /**
     * @param value Name of the Container App secret from which to pull the auth params.
     */
    @JvmName("vfduobalaqkvrfsq")
    public suspend fun secretRef(`value`: Output<String>) {
        this.secretRef = value
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("bweejmnivtuwfgvt")
    public suspend fun triggerParameter(`value`: Output<String>) {
        this.triggerParameter = value
    }

    /**
     * @param value Name of the Container App secret from which to pull the auth params.
     */
    @JvmName("krfillmorpbcuhou")
    public suspend fun secretRef(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.secretRef = mapped
    }

    /**
     * @param value Trigger Parameter that uses the secret
     */
    @JvmName("updyxfkefjrnipfd")
    public suspend fun triggerParameter(`value`: String?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.triggerParameter = mapped
    }

    internal fun build(): ScaleRuleAuthArgs = ScaleRuleAuthArgs(
        secretRef = secretRef,
        triggerParameter = triggerParameter,
    )
}
